OC.L10N.register(
    "files_external",
    {
    "External storage" : "Stocare externă",
    "Personal" : "Personal",
    "Grant access" : "Permite accesul",
    "Access granted" : "Acces permis",
    "Saved" : "Salvat",
    "Username" : "Nume utilizator",
    "Password" : "Parolă",
    "Save" : "Salvează",
    "None" : "Niciuna",
    "API key" : "Cheie API",
    "Public key" : "Cheie publică",
    "Amazon S3" : "Amazon S3",
    "Hostname" : "Hostname",
    "Port" : "Portul",
    "Region" : "Regiune",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Dropbox" : "Dropbox",
    "Host" : "Gazdă",
    "Local" : "Local",
    "Location" : "Locație",
    "ownCloud" : "ownCloud",
    "Root" : "Root",
    "Share" : "Partajează",
    "Name" : "Nume",
    "Storage type" : "Tip stocare",
    "External Storage" : "Stocare externă",
    "Folder name" : "Denumire director",
    "Configuration" : "Configurație",
    "Add storage" : "Adauga stocare",
    "Delete" : "Șterge",
    "Allow users to mount the following external storage" : "Permite utilizatorilor să monteze următoarea unitate de stocare"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
